==> nextcloud-31.0.9-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/fi.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Ensimmäisen käyttökerran avustaja",
    "Add your profile information! For example your email is needed to receive notifications." : "Lisää profiilitietosi! Esimerkiksi sähköpostiosoitettasi tarvitaan ilmoitusten vastaanottamiseen.",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "Lisää profiilitietosi! Esimerkiksi sähköpostiosoitettasi tarvitaan ilmoitusten vastaanottamiseen ja salasanan palauttamiseen.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Lisää profiilitietosi! Lisää profiilikuva ja koko nimi, jotta sinut on helpompi tunnistaa.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Lisää profiilitietosi! Lisää koko nimesi, jotta sinut on helpompi tunnistaa.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Lisää profiilitietosi! Lisää profiilikuva, jotta sinut on helpompi tunnistaa.",
    "App recommendation: Calendar" : "Sovellussuositus: Kalenteri",
    "Schedule work & meetings, synced with all your devices." : "Aikatauluta työsi ja tapaamisesi synkronoidusti kaikkien laitteitesi välillä.",
    "App recommendation: Contacts" : "Sovellussuositus: Yhteystiedot",
    "Keep your colleagues and friends in one place without leaking their private info." : "Pidä työkaverisi ja kaverisi samassa paikassa vuotamatta heidän yksityisiä tietojaan.",
    "App recommendation: Mail" : "Sovellussuositus: Sähköposti",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Yksinkertainen sähköpostisovellus, joka toimii yhdessä Tiedostojen, Kontaktien ja Kalenterin kanssa.",
    "App recommendation: Tasks" : "Sovellussuositus: Tehtävät",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "Synkronoit tehtäviä eri laitteista Nextcloudiisi ja muokkaa niitä netissä.",
    "App recommendation: Deck" : "Sovellussuositus: Pakka",
    "Kanban style organization for personal planning and team projects." : "Kanban-tyylistä organisointia henkilökohtaiseen suunnitteluun ja ryhmäprojekteihin.",
    "App recommendation: Forms" : "Sovellussuositus: Lomakkeet",
    "Simple surveys and questionnaires, self-hosted" : "Helppoja ja yksinkertaisia kyselyitä omalla palvelimella",
    "App recommendation: Recognize" : "Sovellussuositus: Tunnista",
    "Smart media tagging for Nextcloud" : "Median älykästä merkitsemistä tunnisteilla Nextcloudille",
    "App recommendation: Group folders" : "Sovellussuositus: Ryhmäkansiot",
    "Admin-configured folders shared by everyone in a group." : "Ylläpitäjän määrittämät kansiot jaettuina kaikille ryhmän jäsenille.",
    "App recommendation: Whiteboard" : "Sovellussuositus: Whiteboard",
    "Create and share whiteboards with others and collaborate in real-time." : "Luo ja jaa valkotauluja muiden kanssa, ja tee yhteistyötä reaaliajassa.",
    "Connect your calendar" : "Yhdistä kalenteriisi",
    "Connect your contacts" : "Yhdistä yhteystietoihisi",
    "Access files via WebDAV" : "Käytä tiedostoja WebDAVin välityksellä",
    "Download macOS/iOS configuration profile" : "Lataa macOS-/iOS-asetusprofiili",
    "Desktop client" : "Työpöytäsovellus",
    "Android app on Google Play Store" : "Android-sovellus Google Play Storessa",
    "Android app on F-Droid" : "Android-sovellus F-Droidissa",
    "iOS app" : "iOS-sovellus",
    "About & What's new" : "Tietoja & mitä uutta",
    "A welcome and introduction wizard for Nextcloud" : "Nextcloudin ensimmäisen käyttökerran avustaja",
    "Download on Apple app store" : "Lataa Applen sovelluskaupasta",
    "Download on Google play store" : "Lataa Googlen sovelluskaupasta",
    "Go to previous page" : "Siirry edelliselle sivulle",
    "Close" : "Sulje",
    "More about Nextcloud" : "Lisätietoja Nextcloudista",
    "Explore more apps ↗" : "Tutki muita sovelluksia ↗",
    "Extend the functionality of Nextcloud with hundreds of community-developed apps." : "Laajenna Nextcloudin toiminnallisuutta sadoilla yhteisön kehittämillä sovelluksilla.",
    "Get involved! ↗" : "Tule mukaan! ↗",
    "Be a part of the community that helps build, design, translate and promote Nextcloud!" : "Ole osa yhteisöä, joka rakentaa, suunnittelee, kääntää ja edistää Nextcloudia!",
    "Need help? ↗" : "Tarvitsetko apua? ↗",
    "Find out more about your Nextcloud setup with the admin, user or developer documentation." : "Opi lisää Nextcloudin ylläpitäjän, käyttäjän ja kehittäjän dokumentaatiosta.",
    "For large organisations ↗" : "Suurille organisaatioille ↗",
    "Get Nextcloud Enterprise for mission critical environments where advanced security and compliance are important." : "Hanki Nextcloud Enterprise liiketoimintakriittisiin ympäristöihin, joissa tietoturva ja määräystenmukaisuus ovat tärkeitä.",
    "Seamless integration with your devices." : "Saumaton integraatio laitteiden välillä.",
    "Sync your files across your devices with the desktop and mobile apps, and connect your calendar and contacts." : "Synkronoi tiedostot laitteidesi välillä työpöytä- ja mobiilisovellusten avulla, ja yhdistä kalentereihisi sekä yhteystietoihisi.",
    "Desktop app ↗" : "Työpöytäsovellus ↗",
    "Download For Windows, Mac OS and Linux." : "Lataa Windowsille, macOS:lle ja Linuxille.",
    "Calendar and contacts ↗" : "Kalenteri ja yhteystiedot ↗",
    "Connect your calendar and contacts with your devices." : "Yhdistä kalenteri ja yhteystiedot laitteisiisi.",
    "Introducing Nextcloud Hub {version}" : "Esittelyssä Nextcloud Hub versio {version}",
    "Welcome to {cloudName}!" : "Tervetuloa pilveen {cloudName}!",
    "This Nextcloud is on version {version}" : "Tämä Nextcloud on versiossa {version}",
    "A collaboration platform that puts you in control" : "Yhteistyöalusta, joka antaa sinulle hallinnan",
    "Privacy" : "Yksityisyys",
    "Host your data and files where you decide." : "Säilytä tietosi ja tiedostosi missä itse haluat.",
    "Productivity" : "Tuottavuus",
    "Collaborate and communicate across any platform." : "Tee yhteistyötä ja ole yhteydessä kaikkien alustojen välillä.",
    "Interoperability" : "Yhteentoimivuus",
    "Import and export anything you want with open standards." : "Tuo ja vie mitä tahansa avoimiin standardeihin perustuen.",
    "Community" : "Yhteisö",
    "Enjoy constant improvements from a thriving open-source community." : "Nauti jatkuvista parannuksista kukoistavan avoimen lähdekoodin yhteisön toimesta.",
    "Nextcloud Hub {version} release" : "Nextcloud Hub {version} -julkaisu",
    "Read more about it on the Nextcloud Hub {version} blog" : "Lue lisää Nextcloud Hub {version} -blogista",
    "Find out more on the blog" : "Lue lisää blogista",
    "Read the Nextcloud Hub {version} blog" : "Lue Nextcloud Hub {version} -blogia",
    "Share via email" : "Jaa sähköpostitse",
    "New in Nextcloud Hub {version}" : "Uutta Nextcloud Hubin versiossa {version}",
    "Get the apps to sync your files" : "Aseta sovellukset synkronoimaan tiedostosi",
    "URL copied" : "Verkko-osoite kopioitu",
    "Server address" : "Palvelimen osoite",
    "Use this link to connect your apps and desktop client to this server:" : "Käytä tätä linkkiä yhdistääksesi sovellukset ja työpöytäsovelluksen tähän palvelimeen:",
    "… and much more!" : "… ja paljon muuta!",
    "What's new?" : "Mitä uutta?",
    "Nextcloud on all your devices" : "Nextcloud kaikilla laitteillasi",
    "Read more" : "Lue lisää",
    "Share on social media" : "Jaa sosiaalisessa mediassa",
    "Get started!" : "Aloitetaan!",
    "App recommendation: Nextcloud Calendar" : "Sovellussuositus: Nextcloud-kalenteri",
    "App recommendation: Nextcloud Contacts" : "Sovellussuositus: Nextcloud-yhteystiedot",
    "App recommendation: Nextcloud Mail" : "Sovellussuositus: Nextcloud-sähköposti",
    "Workflow Engine" : "Työnkulkumoottori",
    "Office and PDF templates" : "Office- ja PDF-mallipohjat",
    "Your own new personal assistant" : "Uusi henkilökohtainen avustajasi"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/fi.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Ensimmäisen käyttökerran avustaja",
    "Add your profile information! For example your email is needed to receive notifications." : "Lisää profiilitietosi! Esimerkiksi sähköpostiosoitettasi tarvitaan ilmoitusten vastaanottamiseen.",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "Lisää profiilitietosi! Esimerkiksi sähköpostiosoitettasi tarvitaan ilmoitusten vastaanottamiseen ja salasanan palauttamiseen.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Lisää profiilitietosi! Lisää profiilikuva ja koko nimi, jotta sinut on helpompi tunnistaa.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Lisää profiilitietosi! Lisää koko nimesi, jotta sinut on helpompi tunnistaa.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Lisää profiilitietosi! Lisää profiilikuva, jotta sinut on helpompi tunnistaa.",
    "App recommendation: Calendar" : "Sovellussuositus: Kalenteri",
    "Schedule work & meetings, synced with all your devices." : "Aikatauluta työsi ja tapaamisesi synkronoidusti kaikkien laitteitesi välillä.",
    "App recommendation: Contacts" : "Sovellussuositus: Yhteystiedot",
    "Keep your colleagues and friends in one place without leaking their private info." : "Pidä työkaverisi ja kaverisi samassa paikassa vuotamatta heidän yksityisiä tietojaan.",
    "App recommendation: Mail" : "Sovellussuositus: Sähköposti",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Yksinkertainen sähköpostisovellus, joka toimii yhdessä Tiedostojen, Kontaktien ja Kalenterin kanssa.",
    "App recommendation: Tasks" : "Sovellussuositus: Tehtävät",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "Synkronoit tehtäviä eri laitteista Nextcloudiisi ja muokkaa niitä netissä.",
    "App recommendation: Deck" : "Sovellussuositus: Pakka",
    "Kanban style organization for personal planning and team projects." : "Kanban-tyylistä organisointia henkilökohtaiseen suunnitteluun ja ryhmäprojekteihin.",
    "App recommendation: Forms" : "Sovellussuositus: Lomakkeet",
    "Simple surveys and questionnaires, self-hosted" : "Helppoja ja yksinkertaisia kyselyitä omalla palvelimella",
    "App recommendation: Recognize" : "Sovellussuositus: Tunnista",
    "Smart media tagging for Nextcloud" : "Median älykästä merkitsemistä tunnisteilla Nextcloudille",
    "App recommendation: Group folders" : "Sovellussuositus: Ryhmäkansiot",
    "Admin-configured folders shared by everyone in a group." : "Ylläpitäjän määrittämät kansiot jaettuina kaikille ryhmän jäsenille.",
    "App recommendation: Whiteboard" : "Sovellussuositus: Whiteboard",
    "Create and share whiteboards with others and collaborate in real-time." : "Luo ja jaa valkotauluja muiden kanssa, ja tee yhteistyötä reaaliajassa.",
    "Connect your calendar" : "Yhdistä kalenteriisi",
    "Connect your contacts" : "Yhdistä yhteystietoihisi",
    "Access files via WebDAV" : "Käytä tiedostoja WebDAVin välityksellä",
    "Download macOS/iOS configuration profile" : "Lataa macOS-/iOS-asetusprofiili",
    "Desktop client" : "Työpöytäsovellus",
    "Android app on Google Play Store" : "Android-sovellus Google Play Storessa",
    "Android app on F-Droid" : "Android-sovellus F-Droidissa",
    "iOS app" : "iOS-sovellus",
    "About & What's new" : "Tietoja & mitä uutta",
    "A welcome and introduction wizard for Nextcloud" : "Nextcloudin ensimmäisen käyttökerran avustaja",
    "Download on Apple app store" : "Lataa Applen sovelluskaupasta",
    "Download on Google play store" : "Lataa Googlen sovelluskaupasta",
    "Go to previous page" : "Siirry edelliselle sivulle",
    "Close" : "Sulje",
    "More about Nextcloud" : "Lisätietoja Nextcloudista",
    "Explore more apps ↗" : "Tutki muita sovelluksia ↗",
    "Extend the functionality of Nextcloud with hundreds of community-developed apps." : "Laajenna Nextcloudin toiminnallisuutta sadoilla yhteisön kehittämillä sovelluksilla.",
    "Get involved! ↗" : "Tule mukaan! ↗",
    "Be a part of the community that helps build, design, translate and promote Nextcloud!" : "Ole osa yhteisöä, joka rakentaa, suunnittelee, kääntää ja edistää Nextcloudia!",
    "Need help? ↗" : "Tarvitsetko apua? ↗",
    "Find out more about your Nextcloud setup with the admin, user or developer documentation." : "Opi lisää Nextcloudin ylläpitäjän, käyttäjän ja kehittäjän dokumentaatiosta.",
    "For large organisations ↗" : "Suurille organisaatioille ↗",
    "Get Nextcloud Enterprise for mission critical environments where advanced security and compliance are important." : "Hanki Nextcloud Enterprise liiketoimintakriittisiin ympäristöihin, joissa tietoturva ja määräystenmukaisuus ovat tärkeitä.",
    "Seamless integration with your devices." : "Saumaton integraatio laitteiden välillä.",
    "Sync your files across your devices with the desktop and mobile apps, and connect your calendar and contacts." : "Synkronoi tiedostot laitteidesi välillä työpöytä- ja mobiilisovellusten avulla, ja yhdistä kalentereihisi sekä yhteystietoihisi.",
    "Desktop app ↗" : "Työpöytäsovellus ↗",
    "Download For Windows, Mac OS and Linux." : "Lataa Windowsille, macOS:lle ja Linuxille.",
    "Calendar and contacts ↗" : "Kalenteri ja yhteystiedot ↗",
    "Connect your calendar and contacts with your devices." : "Yhdistä kalenteri ja yhteystiedot laitteisiisi.",
    "Introducing Nextcloud Hub {version}" : "Esittelyssä Nextcloud Hub versio {version}",
    "Welcome to {cloudName}!" : "Tervetuloa pilveen {cloudName}!",
    "This Nextcloud is on version {version}" : "Tämä Nextcloud on versiossa {version}",
    "A collaboration platform that puts you in control" : "Yhteistyöalusta, joka antaa sinulle hallinnan",
    "Privacy" : "Yksityisyys",
    "Host your data and files where you decide." : "Säilytä tietosi ja tiedostosi missä itse haluat.",
    "Productivity" : "Tuottavuus",
    "Collaborate and communicate across any platform." : "Tee yhteistyötä ja ole yhteydessä kaikkien alustojen välillä.",
    "Interoperability" : "Yhteentoimivuus",
    "Import and export anything you want with open standards." : "Tuo ja vie mitä tahansa avoimiin standardeihin perustuen.",
    "Community" : "Yhteisö",
    "Enjoy constant improvements from a thriving open-source community." : "Nauti jatkuvista parannuksista kukoistavan avoimen lähdekoodin yhteisön toimesta.",
    "Nextcloud Hub {version} release" : "Nextcloud Hub {version} -julkaisu",
    "Read more about it on the Nextcloud Hub {version} blog" : "Lue lisää Nextcloud Hub {version} -blogista",
    "Find out more on the blog" : "Lue lisää blogista",
    "Read the Nextcloud Hub {version} blog" : "Lue Nextcloud Hub {version} -blogia",
    "Share via email" : "Jaa sähköpostitse",
    "Share on {socialMedia}" : "Jaa: {socialMedia}",
    "New in Nextcloud Hub {version}" : "Uutta Nextcloud Hubin versiossa {version}",
    "Connect other apps to {productName}" : "Yhdistä muita sovelluksia {productName}iin",
    "Get the apps to sync your files" : "Aseta sovellukset synkronoimaan tiedostosi",
    "URL copied" : "Verkko-osoite kopioitu",
    "Server address" : "Palvelimen osoite",
    "Use this link to connect your apps and desktop client to this server:" : "Käytä tätä linkkiä yhdistääksesi sovellukset ja työpöytäsovelluksen tähän palvelimeen:",
    "… and much more!" : "… ja paljon muuta!",
    "What's new?" : "Mitä uutta?",
    "Nextcloud on all your devices" : "Nextcloud kaikilla laitteillasi",
    "Read more" : "Lue lisää",
    "Share on social media" : "Jaa sosiaalisessa mediassa",
    "Get started!" : "Aloitetaan!",
    "Your own new personal assistant" : "Uusi henkilökohtainen avustajasi"
},
"nplurals=2; plural=(n != 1);");
